@@ -183,7 +183,7 @@ static void new_clicked(GtkWidget *b, gpointer data) {
 }
 
 static void guide_clicked(GtkWidget *b, gpointer data) {
-	system("dbus-send --print-reply --dest=com.nokia.osso_browser /com/nokia/osso_browser/service com.nokia.osso_browser.open_new_window string:file:///usr/share/doc/100boxes/index.html");
+	system("dbus-send --print-reply --dest=com.nokia.osso_browser /com/nokia/osso_browser/service com.nokia.osso_browser.open_new_window string:file:///usr/share/100boxes/index.html");
 }
 
 void new_game(struct game_data *d) {
